@@ -6,20 +6,22 @@ import (
 	"reflect"
 	"strconv"
 
-	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/client-go/rest"
-
 	gstorage "cloud.google.com/go/storage"
 	goauth2 "golang.org/x/oauth2/google"
 	gapi "google.golang.org/api/googleapi"
 	goption "google.golang.org/api/option"
 
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/errors"
+	"k8s.io/client-go/rest"
+
 	configapiv1 "github.com/openshift/api/config/v1"
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
+
 	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 )
 
@@ -111,22 +113,11 @@ func GetConfig(listers *regopclient.Listers) (*GCS, error) {
 	return gcsConfig, nil
 }
 
-func (d *driver) Secrets() (map[string]string, error) {
-	cfg, err := GetConfig(d.Listers)
-	if err != nil {
-		return nil, err
-	}
-
-	return map[string]string{
-		"REGISTRY_STORAGE_GCS_KEYFILE": cfg.KeyfileData,
-	}, nil
-}
-
-func (d *driver) ConfigEnv() (envs []corev1.EnvVar, err error) {
+func (d *driver) ConfigEnv() (envs envvar.List, err error) {
 	envs = append(envs,
-		corev1.EnvVar{Name: "REGISTRY_STORAGE", Value: "gcs"},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_GCS_BUCKET", Value: d.Config.Bucket},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_GCS_KEYFILE", Value: "/gcs/keyfile"},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE", Value: "gcs"},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_GCS_BUCKET", Value: d.Config.Bucket},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_GCS_KEYFILE", Value: "/gcs/keyfile"},
 	)
 	return
 }
@@ -158,6 +149,17 @@ func (d *driver) Volumes() ([]corev1.Volume, []corev1.VolumeMount, error) {
 	return []corev1.Volume{vol}, []corev1.VolumeMount{mount}, nil
 }
 
+func (d *driver) VolumeSecrets() (map[string]string, error) {
+	cfg, err := GetConfig(d.Listers)
+	if err != nil {
+		return nil, err
+	}
+
+	return map[string]string{
+		"REGISTRY_STORAGE_GCS_KEYFILE": cfg.KeyfileData,
+	}, nil
+}
+
 func (d *driver) bucketExists(bucketName string) error {
 	client, err := d.getGCSClient()
 	if err != nil {
@@ -236,37 +238,32 @@ func (d *driver) CreateStorage(cr *imageregistryv1.Config) error {
 		util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionTrue, "GCS Bucket Exists", "User supplied GCS bucket exists and is accessible")
 
 	} else {
-		const numRetries = 5000
-		for i := 0; i < numRetries; i++ {
-			// If the bucket name is blank, let's generate one
-			if len(d.Config.Bucket) == 0 {
-				if d.Config.Bucket, err = util.GenerateStorageName(d.Listers, d.Config.Region); err != nil {
-					return err
-				}
+		// If the bucket name is blank, let's generate one
+		if len(d.Config.Bucket) == 0 {
+			if d.Config.Bucket, err = util.GenerateStorageName(d.Listers, d.Config.Region); err != nil {
+				return err
 			}
-			bucketAttrs := gstorage.BucketAttrs{Location: d.Config.Region}
-			bucket = gclient.Bucket(d.Config.Bucket)
-
-			err := bucket.Create(d.Context, d.Config.ProjectID, &bucketAttrs)
-			if err != nil {
-				if gerr, ok := err.(*gapi.Error); ok {
-					util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, strconv.Itoa(gerr.Code), gerr.Error())
-					return err
-				} else {
-					util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, "Unknown Error Occurred", err.Error())
-					return err
-				}
-			}
-			cr.Status.StorageManaged = true
-			cr.Status.Storage = imageregistryv1.ImageRegistryConfigStorage{
-				GCS: d.Config.DeepCopy(),
-			}
-			cr.Spec.Storage.GCS = d.Config.DeepCopy()
-
-			util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionTrue, "Creation Successful", "GCS bucket was successfully created")
-
-			break
 		}
+		bucketAttrs := gstorage.BucketAttrs{Location: d.Config.Region}
+		bucket = gclient.Bucket(d.Config.Bucket)
+
+		err := bucket.Create(d.Context, d.Config.ProjectID, &bucketAttrs)
+		if err != nil {
+			if gerr, ok := err.(*gapi.Error); ok {
+				util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, strconv.Itoa(gerr.Code), gerr.Error())
+				return err
+			} else {
+				util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, "Unknown Error Occurred", err.Error())
+				return err
+			}
+		}
+		cr.Status.StorageManaged = true
+		cr.Status.Storage = imageregistryv1.ImageRegistryConfigStorage{
+			GCS: d.Config.DeepCopy(),
+		}
+		cr.Spec.Storage.GCS = d.Config.DeepCopy()
+
+		util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionTrue, "Creation Successful", "GCS bucket was successfully created")
 
 		if len(d.Config.Bucket) == 0 {
 			util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, "Unable to Generate Unique Bucket Name", "")
